# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_ROI_ROW_PY_METADATA = Metadata(
    id="cada95873436e89bd665259b6c2d18bfee6eb649.boutiques",
    name="fat_roi_row.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatRoiRowPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_roi_row_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Selected ROI row output file in .row format."""


def fat_roi_row_py(
    roi: str,
    matrix_files: str | None = None,
    list_file: InputPathType | None = None,
    extern_labs_no: bool = False,
    runner: Runner | None = None,
) -> FatRoiRowPyOutputs:
    """
    Select a single ROI's row out of a connectivity matrix file (*.grid or *.netcc)
    for viewing and/or further analysis.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/fat_roi_row.py.html
    
    Args:
        roi: Specify which ROI's row of connectivity you want to select out. If\
            labeltables were used, you may select the ROI by either the string\
            label or the ROI mask number.
        matrix_files: Provide the set of matrix (*.grid or *.netcc) files by\
            searchable path. This can be a globbable entry in quotes containing\
            wildcard characters.
        list_file: Provide the set of matrix (*.grid or *.netcc) files by\
            explicit path in a text file. The LIST text file must contain at least\
            one column with the path to subject matrix file.
        extern_labs_no: Switch to turn off the writing/usage of user-defined\
            labels in the *.grid/*.netcc files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatRoiRowPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_ROI_ROW_PY_METADATA)
    cargs = []
    cargs.append("fat_roi_row.py")
    cargs.append("-r")
    cargs.extend([
        "-r",
        roi
    ])
    cargs.append("{")
    cargs.append("-m")
    if matrix_files is not None:
        cargs.extend([
            "-m",
            matrix_files
        ])
    cargs.append("|")
    cargs.append("-l")
    if list_file is not None:
        cargs.extend([
            "-l",
            execution.input_file(list_file)
        ])
    cargs.append("}")
    cargs.append("-E")
    if extern_labs_no:
        cargs.append("-E")
    ret = FatRoiRowPyOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(roi + "_selected.row"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_ROI_ROW_PY_METADATA",
    "FatRoiRowPyOutputs",
    "fat_roi_row_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_WEDGE_VOLUME_METADATA = Metadata(
    id="2d72a72882b2565f0b41eca27d7216402a57fa1e.boutiques",
    name="surface-wedge-volume",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceWedgeVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_wedge_volume(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric: OutputPathType
    """the output metric"""


def surface_wedge_volume(
    inner_surface: InputPathType,
    outer_surface: InputPathType,
    metric: str,
    runner: Runner | None = None,
) -> SurfaceWedgeVolumeOutputs:
    """
    Measure per-vertex volume between surfaces.
    
    Compute the volume of each vertex's area from one surface to another. The
    surfaces must have vertex correspondence, and have consistent triangle
    orientation.
    
    Author: Washington University School of Medicin
    
    Args:
        inner_surface: the inner surface.
        outer_surface: the outer surface.
        metric: the output metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceWedgeVolumeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_WEDGE_VOLUME_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-wedge-volume")
    cargs.append(execution.input_file(inner_surface))
    cargs.append(execution.input_file(outer_surface))
    cargs.append(metric)
    ret = SurfaceWedgeVolumeOutputs(
        root=execution.output_file("."),
        metric=execution.output_file(metric),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_WEDGE_VOLUME_METADATA",
    "SurfaceWedgeVolumeOutputs",
    "surface_wedge_volume",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DCALC_METADATA = Metadata(
    id="dcccd0bd8b013fd4d58815a538c1d07ba5d9c31d.boutiques",
    name="3dcalc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dcalcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dcalc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output image file name."""


def v_3dcalc(
    in_file_a: InputPathType,
    expr: str,
    in_file_b: InputPathType | None = None,
    in_file_c: InputPathType | None = None,
    other: InputPathType | None = None,
    overwrite: bool = False,
    single_idx: int | None = None,
    start_idx: int | None = None,
    stop_idx: int | None = None,
    runner: Runner | None = None,
) -> V3dcalcOutputs:
    """
    AFNI's calculator program.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dcalc.html
    
    Args:
        in_file_a: Input file to 3dcalc.
        expr: Expr.
        in_file_b: Operand file to 3dcalc.
        in_file_c: Operand file to 3dcalc.
        other: Other options.
        overwrite: Overwrite output.
        single_idx: Volume index for in_file_a.
        start_idx: Start index for in_file_a.
        stop_idx: Stop index for in_file_a.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dcalcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DCALC_METADATA)
    cargs = []
    cargs.append("3dcalc")
    cargs.extend([
        "-a",
        execution.input_file(in_file_a)
    ])
    if in_file_b is not None:
        cargs.extend([
            "-b",
            execution.input_file(in_file_b)
        ])
    if in_file_c is not None:
        cargs.extend([
            "-c",
            execution.input_file(in_file_c)
        ])
    cargs.append("-expr")
    cargs.append(expr)
    if other is not None:
        cargs.append(execution.input_file(other))
    cargs.append("[OUT_FILE]")
    if overwrite:
        cargs.append("-overwrite")
    if single_idx is not None:
        cargs.append(str(single_idx))
    if start_idx is not None:
        cargs.append(str(start_idx))
    if stop_idx is not None:
        cargs.append(str(stop_idx))
    ret = V3dcalcOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file_a).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dcalcOutputs",
    "V_3DCALC_METADATA",
    "v_3dcalc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DEPTH_MAP_METADATA = Metadata(
    id="7dd1629cdf258c181c4153516b25cd08a25b0030.boutiques",
    name="3dDepthMap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDepthMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_depth_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Main output file"""


def v_3d_depth_map(
    output_prefix: str,
    input_dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dDepthMapOutputs:
    """
    Calculates the Euclidean Distance Transform (EDT) for 3D volumes, allowing
    computation of ROI depth maps and applying various adjustments like masking and
    rimification.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dDepthMap.html
    
    Args:
        output_prefix: Output prefix name.
        input_dataset: Input dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDepthMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DEPTH_MAP_METADATA)
    cargs = []
    cargs.append("3dDepthMap")
    cargs.append("[OPTIONS]")
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        output_prefix
    ])
    cargs.append("-input")
    cargs.extend([
        "-input",
        execution.input_file(input_dataset)
    ])
    ret = V3dDepthMapOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_prefix + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDepthMapOutputs",
    "V_3D_DEPTH_MAP_METADATA",
    "v_3d_depth_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__AUTO_TLRC_METADATA = Metadata(
    id="f82082ae0a2d8a6159b5e2fd4df475fad6592653.boutiques",
    name="@auto_tlrc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAutoTlrcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__auto_tlrc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Transformed anatomical volume dataset in TLRC space."""
    transform_file: OutputPathType
    """Transform used to align the anatomical dataset to the template."""


def v__auto_tlrc(
    runner: Runner | None = None,
) -> VAutoTlrcOutputs:
    """
    A script to transform an anatomical dataset to align with some standard space
    template and to apply the same TLRC transform obtained with @auto_tlrc in Usage
    1 mode to other datasets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@auto_tlrc.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAutoTlrcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__AUTO_TLRC_METADATA)
    cargs = []
    cargs.append("@auto_tlrc")
    cargs.append("[OPTIONS]")
    cargs.append("<-base")
    cargs.append("template>")
    cargs.append("<-input")
    cargs.append("anat>")
    ret = VAutoTlrcOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file("[PREFIX].nii.gz"),
        transform_file=execution.output_file("[PREFIX].Xat.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAutoTlrcOutputs",
    "V__AUTO_TLRC_METADATA",
    "v__auto_tlrc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_GEN_FEATURE_DIST_METADATA = Metadata(
    id="199bdb69edfe9e06ea3902546ede4dde87cb2831.boutiques",
    name="3dGenFeatureDist",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dGenFeatureDistOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_gen_feature_dist(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_hive: OutputPathType | None
    """Histogram volume output"""


def v_3d_gen_feature_dist(
    features_string: str,
    class_string: str,
    prefix: str | None = None,
    overwrite: bool = False,
    debug_level: float | None = None,
    other: bool = False,
    no_other: bool = False,
    show_histograms: str | None = None,
    runner: Runner | None = None,
) -> V3dGenFeatureDistOutputs:
    """
    3dGenFeatureDist produces histogram volume (hives) from input data.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dGenFeatureDist.html
    
    Args:
        features_string: FEATURES_STRING is a semicolon delimited string of\
            features.
        class_string: CLASS_STRING is a semicolon delimited string of class\
            labels.
        prefix: PREF is the prefix for all output volumes that are not\
            debugging related.
        overwrite: Automatically overwrite existing output.
        debug_level: Debugging level.
        other: Add histograms for an 'OTHER' class that has a uniform pdf.
        no_other: Opposite of -OTHER.
        show_histograms: Show specified histograms and quit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dGenFeatureDistOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_GEN_FEATURE_DIST_METADATA)
    cargs = []
    cargs.append("3dGenFeatureDist")
    cargs.extend([
        "-features",
        features_string
    ])
    cargs.extend([
        "-classes",
        class_string
    ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if overwrite:
        cargs.append("-overwrite")
    if debug_level is not None:
        cargs.extend([
            "-debug",
            str(debug_level)
        ])
    if other:
        cargs.append("-OTHER")
    if no_other:
        cargs.append("-no_OTHER")
    if show_histograms is not None:
        cargs.extend([
            "-ShowTheseHists",
            show_histograms
        ])
    ret = V3dGenFeatureDistOutputs(
        root=execution.output_file("."),
        output_hive=execution.output_file(prefix + "_hive.nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dGenFeatureDistOutputs",
    "V_3D_GEN_FEATURE_DIST_METADATA",
    "v_3d_gen_feature_dist",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_MASK_METADATA = Metadata(
    id="8b0c7834f326fc5492985a67883c6b3a2ba9c186.boutiques",
    name="metric-mask",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class MetricMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_mask(
    metric: InputPathType,
    mask: InputPathType,
    metric_out: str,
    opt_column_column: str | None = None,
    runner: Runner | None = None,
) -> MetricMaskOutputs:
    """
    Mask a metric file.
    
    By default, the output metric is a copy of the input metric, but with zeros
    wherever the mask metric is zero or negative. if -column is specified, the
    output contains only one column, the masked version of the specified input
    column.
    
    Author: Washington University School of Medicin
    
    Args:
        metric: the input metric.
        mask: the mask metric.
        metric_out: the output metric.
        opt_column_column: select a single column: the column number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricMaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_MASK_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-mask")
    cargs.append(execution.input_file(metric))
    cargs.append(execution.input_file(mask))
    cargs.append(metric_out)
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    ret = MetricMaskOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_MASK_METADATA",
    "MetricMaskOutputs",
    "metric_mask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GIFTI_TOOL_METADATA = Metadata(
    id="91ee7bba9d5abb27f280ff9aec49c977815a1d13.boutiques",
    name="gifti_tool",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GiftiToolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gifti_tool(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_gifti: OutputPathType
    """Output GIFTI file"""


def gifti_tool(
    runner: Runner | None = None,
) -> GiftiToolOutputs:
    """
    Tool for creating, displaying, modifying, or comparing GIFTI datasets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/gifti_tool.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiToolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GIFTI_TOOL_METADATA)
    cargs = []
    cargs.append("gifti_tool")
    cargs.append("[ARGS]")
    ret = GiftiToolOutputs(
        root=execution.output_file("."),
        output_gifti=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GIFTI_TOOL_METADATA",
    "GiftiToolOutputs",
    "gifti_tool",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ANATICOR_METADATA = Metadata(
    id="3db66aed89c32fcb65e127aa5c1e9c35942e3278.boutiques",
    name="@ANATICOR",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAnaticorOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__anaticor(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Output files with the prefix specified by the -prefix option."""


def v__anaticor(
    ts: InputPathType,
    polort: str,
    motion: InputPathType,
    aseg: InputPathType,
    prefix: str,
    radius: float | None = None,
    view: str | None = None,
    nuisance: InputPathType | None = None,
    no_ventricles: bool = False,
    rsq_wme: bool = False,
    coverage: bool = False,
    verb: bool = False,
    dirty: bool = False,
    echo: bool = False,
    runner: Runner | None = None,
) -> VAnaticorOutputs:
    """
    Script to produce a residual time series cleaned by ANATICOR model.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@ANATICOR.html
    
    Args:
        ts: Time series volume which should have already undergone\
            preprocessing steps such as despiking, RetroIcor, RVT correction, time\
            shifting, and volume registration.
        polort: Polynomial for linear trend removal. Use the same order as for\
            afni_proc.py.
        motion: Head motion parameters from 3dvolreg, also created by\
            afni_proc.py.
        aseg: Aseg file from FreeSurfer's segmentation. This aseg volume must\
            be in register with the EPI time series.
        prefix: Use output (residual time series) for a prefix.
        radius: The radius of a local sphere mask in mm. Default is 15 mm for\
            high resolution 1.7x1.7x3mm data.
        view: Set the view of the output data. Default is +orig. Choose from\
            +orig, +acpc, or +tlrc.
        nuisance: Other nuisance regressors. Each regressor is a column in .1D\
            file.
        no_ventricles: Do not include LVe regressor.
        rsq_wme: Produce an explained variance map for WMeLOCAL regressor.
        coverage: Produce a spatial coverage map of WMeLOCAL regressor.
        verb: Verbose flag.
        dirty: Keep temporary files.
        echo: Echo each script command for debugging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAnaticorOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ANATICOR_METADATA)
    cargs = []
    cargs.append("@ANATICOR")
    cargs.extend([
        "-ts",
        execution.input_file(ts)
    ])
    cargs.extend([
        "-polort",
        polort
    ])
    cargs.extend([
        "-motion",
        execution.input_file(motion)
    ])
    cargs.append(execution.input_file(aseg))
    cargs.extend([
        "-prefix",
        prefix
    ])
    if radius is not None:
        cargs.extend([
            "-radius",
            str(radius)
        ])
    if view is not None:
        cargs.append(view)
    if nuisance is not None:
        cargs.extend([
            "-nuisance",
            execution.input_file(nuisance)
        ])
    if no_ventricles:
        cargs.append("-no_ventricles")
    if rsq_wme:
        cargs.append("-Rsq_WMe")
    if coverage:
        cargs.append("-coverage")
    if verb:
        cargs.append("-verb")
    if dirty:
        cargs.append("-dirty")
    if echo:
        cargs.append("-echo")
    ret = VAnaticorOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(prefix),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAnaticorOutputs",
    "V__ANATICOR_METADATA",
    "v__anaticor",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_DILATE_METADATA = Metadata(
    id="a0cc77e029a17feca7009ae856be1f20bac8d8a1.boutiques",
    name="volume-dilate",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class VolumeDilatePresmooth:
    """
    apply presmoothing before computing gradient vectors, not recommended.
    """
    kernel: float
    """the size of gaussian smoothing kernel in mm, as sigma by default"""
    opt_fwhm: bool = False
    """kernel size is FWHM, not sigma"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-presmooth")
        cargs.append(str(self.kernel))
        if self.opt_fwhm:
            cargs.append("-fwhm")
        return cargs


class VolumeDilateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_dilate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_dilate(
    volume: InputPathType,
    distance: float,
    method: str,
    volume_out: str,
    opt_exponent_exponent: float | None = None,
    opt_bad_voxel_roi_roi_volume: InputPathType | None = None,
    opt_data_roi_roi_volume: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    opt_legacy_cutoff: bool = False,
    opt_grad_extrapolate: bool = False,
    presmooth: VolumeDilatePresmooth | None = None,
    runner: Runner | None = None,
) -> VolumeDilateOutputs:
    """
    Dilate a volume file.
    
    For all voxels that are designated as bad, if they neighbor a non-bad voxel
    with data or are within the specified distance of such a voxel, replace the
    value in the bad voxel with a value calculated from nearby non-bad voxels
    that have data, otherwise set the value to zero. No matter how small
    <distance> is, dilation will always use at least the face neighbor voxels.
    
    By default, voxels that have data with the value 0 are bad, specify
    -bad-voxel-roi to only count voxels as bad if they are selected by the roi.
    If -data-roi is not specified, all voxels are assumed to have data.
    
    To get the behavior of version 1.3.2 or earlier, use '-legacy-cutoff
    -exponent 2'.
    
    Valid values for <method> are:
    
    NEAREST - use the value from the nearest good voxel
    WEIGHTED - use a weighted average based on distance.
    
    Author: Washington University School of Medicin
    
    Args:
        volume: the volume to dilate.
        distance: distance in mm to dilate.
        method: dilation method to use.
        volume_out: the output volume.
        opt_exponent_exponent: use a different exponent in the weighting\
            function: exponent 'n' to use in (1 / (distance ^ n)) as the weighting\
            function (default 7).
        opt_bad_voxel_roi_roi_volume: specify an roi of voxels to overwrite,\
            rather than voxels with value zero: volume file, positive values denote\
            voxels to have their values replaced.
        opt_data_roi_roi_volume: specify an roi of where there is data: volume\
            file, positive values denote voxels that have data.
        opt_subvolume_subvol: select a single subvolume to dilate: the\
            subvolume number or name.
        opt_legacy_cutoff: use the v1.3.2 method of excluding voxels further\
            than the dilation distance when calculating the dilated value.
        opt_grad_extrapolate: additionally use the gradient to extrapolate,\
            intended to be used with WEIGHTED.
        presmooth: apply presmoothing before computing gradient vectors, not\
            recommended.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeDilateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_DILATE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-dilate")
    cargs.append(execution.input_file(volume))
    cargs.append(str(distance))
    cargs.append(method)
    cargs.append(volume_out)
    if opt_exponent_exponent is not None:
        cargs.extend([
            "-exponent",
            str(opt_exponent_exponent)
        ])
    if opt_bad_voxel_roi_roi_volume is not None:
        cargs.extend([
            "-bad-voxel-roi",
            execution.input_file(opt_bad_voxel_roi_roi_volume)
        ])
    if opt_data_roi_roi_volume is not None:
        cargs.extend([
            "-data-roi",
            execution.input_file(opt_data_roi_roi_volume)
        ])
    if opt_subvolume_subvol is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvol
        ])
    if opt_legacy_cutoff:
        cargs.append("-legacy-cutoff")
    if opt_grad_extrapolate:
        cargs.append("-grad-extrapolate")
    if presmooth is not None:
        cargs.extend(presmooth.run(execution))
    ret = VolumeDilateOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_DILATE_METADATA",
    "VolumeDilateOutputs",
    "VolumeDilatePresmooth",
    "volume_dilate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DSUM_METADATA = Metadata(
    id="b7285695a2ae3b620b57d991f8488c79f4e12c53.boutiques",
    name="1dsum",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dsumOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dsum(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Sum or average of columns in the input files"""


def v_1dsum(
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> V1dsumOutputs:
    """
    Sum or average columns of ASCII files with numbers arranged in rows and columns.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dsum.html
    
    Args:
        input_files: Input ASCII files with numbers arranged in rows and\
            columns.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dsumOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DSUM_METADATA)
    cargs = []
    cargs.append("1dsum")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = V1dsumOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dsumOutputs",
    "V_1DSUM_METADATA",
    "v_1dsum",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SYNTHSTRIP_METADATA = Metadata(
    id="fb880e3e88b019dc0ec0078b71a89815251f3260.boutiques",
    name="mri_synthstrip",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSynthstripOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_synthstrip(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_image_file: OutputPathType | None
    """File containing the stripped image"""
    mask_image_file: OutputPathType | None
    """File containing the binary brain mask"""
    sdt_image_file: OutputPathType | None
    """File containing the distance transform"""


def mri_synthstrip(
    input_image: InputPathType,
    out_file: str | None = None,
    mask_file: str | None = None,
    sdt_file: str | None = None,
    gpu_flag: bool = False,
    border_threshold: float | None = None,
    num_threads: float | None = None,
    no_csf_flag: bool = False,
    model_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriSynthstripOutputs:
    """
    Robust, universal skull-stripping for brain images of any type.
    
    Author: Unknown
    
    URL: https://example.com/universal_skullstrip_docs
    
    Args:
        input_image: Input image to skullstrip.
        out_file: Filename to save the stripped image.
        mask_file: Filename to save the binary brain mask.
        sdt_file: Filename to save the distance transform.
        gpu_flag: Use the GPU.
        border_threshold: Mask border threshold in mm, defaults to 1.
        num_threads: PyTorch CPU threads; uses PyTorch default if unset.
        no_csf_flag: Exclude CSF from the brain border.
        model_file: Alternative model weights.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSynthstripOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SYNTHSTRIP_METADATA)
    cargs = []
    cargs.append("mri_synthstrip")
    cargs.extend([
        "-i",
        execution.input_file(input_image)
    ])
    if out_file is not None:
        cargs.extend([
            "-o",
            out_file
        ])
    if mask_file is not None:
        cargs.extend([
            "-m",
            mask_file
        ])
    if sdt_file is not None:
        cargs.extend([
            "-d",
            sdt_file
        ])
    if gpu_flag:
        cargs.append("-g")
    if border_threshold is not None:
        cargs.extend([
            "-b",
            str(border_threshold)
        ])
    if num_threads is not None:
        cargs.extend([
            "-t",
            str(num_threads)
        ])
    if no_csf_flag:
        cargs.append("--no-csf")
    if model_file is not None:
        cargs.extend([
            "--model",
            execution.input_file(model_file)
        ])
    ret = MriSynthstripOutputs(
        root=execution.output_file("."),
        out_image_file=execution.output_file(out_file) if (out_file is not None) else None,
        mask_image_file=execution.output_file(mask_file) if (mask_file is not None) else None,
        sdt_image_file=execution.output_file(sdt_file) if (sdt_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SYNTHSTRIP_METADATA",
    "MriSynthstripOutputs",
    "mri_synthstrip",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_SBCA_METADATA = Metadata(
    id="9a0539cce0afbdc0ad35f76430d92a4e08805154.boutiques",
    name="fsl_sbca",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslSbcaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_sbca(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_seed_mask_image: OutputPathType
    """Output seed mask image"""
    output_seed_mask_image_base: OutputPathType
    """Output seed mask image"""
    output_target_time_courses: OutputPathType
    """Output target time courses"""
    output_confound_time_courses: OutputPathType
    """Output confound time courses"""


def fsl_sbca(
    infile: InputPathType,
    seed: InputPathType,
    target: InputPathType,
    out: str,
    runner: Runner | None = None,
) -> FslSbcaOutputs:
    """
    Performs seed-based correlation analysis on FMRI data using either a single seed
    coordinate or a seed mask.
    
    Author: Christian F. Beckmann
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/SBCA
    
    Args:
        infile: Input file name (4D image file).
        seed: Seed voxel coordinate or file name of seed mask (3D/4D file).
        target: File name of target mask(s) (3D or 4D file).
        out: Output file base name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslSbcaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_SBCA_METADATA)
    cargs = []
    cargs.append("fsl_sbca")
    cargs.append("-i")
    cargs.extend([
        "--in",
        execution.input_file(infile)
    ])
    cargs.append("-s")
    cargs.extend([
        "--seed",
        execution.input_file(seed)
    ])
    cargs.append("-t")
    cargs.extend([
        "--target",
        execution.input_file(target)
    ])
    cargs.append("-o")
    cargs.extend([
        "--out",
        out
    ])
    cargs.append("[OPTIONS]")
    ret = FslSbcaOutputs(
        root=execution.output_file("."),
        output_seed_mask_image=execution.output_file(out + "_seeds"),
        output_seed_mask_image_base=execution.output_file(out + "_seedmask"),
        output_target_time_courses=execution.output_file(out + "_ttc<X>.txt"),
        output_confound_time_courses=execution.output_file(out + "_confounds.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_SBCA_METADATA",
    "FslSbcaOutputs",
    "fsl_sbca",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_FATCAT_DEMO2_METADATA = Metadata(
    id="30d3dec7d043fb270647b12bcab46b5a0618ac86.boutiques",
    name="@Install_FATCAT_DEMO2",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallFatcatDemo2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_fatcat_demo2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__install_fatcat_demo2(
    use_curl: bool = False,
    runner: Runner | None = None,
) -> VInstallFatcatDemo2Outputs:
    """
    Installs the demo archive for Paul Taylor's tractography tools.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_FATCAT_DEMO2.html
    
    Args:
        use_curl: Use curl to download archive.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallFatcatDemo2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_FATCAT_DEMO2_METADATA)
    cargs = []
    cargs.append("@Install_FATCAT_DEMO2")
    if use_curl:
        cargs.append("-curl")
    ret = VInstallFatcatDemo2Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallFatcatDemo2Outputs",
    "V__INSTALL_FATCAT_DEMO2_METADATA",
    "v__install_fatcat_demo2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_NWARP_APPLY_METADATA = Metadata(
    id="302efea392d797dfd8b780375733a817c0908c40.boutiques",
    name="3dNwarpApply",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dNwarpApplyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_nwarp_apply(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    warped_output: OutputPathType
    """Warped output dataset"""
    generated_warp: OutputPathType
    """Warp dataset generated during application"""


def v_3d_nwarp_apply(
    runner: Runner | None = None,
) -> V3dNwarpApplyOutputs:
    """
    Program to apply a nonlinear 3D warp saved from 3dQwarp (or 3dNwarpCat, etc.) to
    a 3D dataset, to produce a warped version of the source dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dNwarpApply.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dNwarpApplyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_NWARP_APPLY_METADATA)
    cargs = []
    cargs.append("3dNwarpApply")
    cargs.append("[OPTIONS]")
    ret = V3dNwarpApplyOutputs(
        root=execution.output_file("."),
        warped_output=execution.output_file("[PREFIX]_[SOURCE]_warped.nii.gz"),
        generated_warp=execution.output_file("[WPREFIX]_warp_????.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dNwarpApplyOutputs",
    "V_3D_NWARP_APPLY_METADATA",
    "v_3d_nwarp_apply",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DDOT_METADATA = Metadata(
    id="18ec3a73314a3e5065dbea40cf4a86cbe46d9ca8.boutiques",
    name="3ddot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3ddotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3ddot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result: OutputPathType
    """Resulting coefficient or statistical values printed to stdout"""


def v_3ddot(
    input_datasets: list[InputPathType],
    runner: Runner | None = None,
) -> V3ddotOutputs:
    """
    Computes correlation coefficients between sub-brick pairs.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3ddot.html
    
    Args:
        input_datasets: List of input datasets to be used (e.g. img1+orig,\
            img2+orig).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3ddotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DDOT_METADATA)
    cargs = []
    cargs.append("3ddot")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in input_datasets])
    ret = V3ddotOutputs(
        root=execution.output_file("."),
        result=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3ddotOutputs",
    "V_3DDOT_METADATA",
    "v_3ddot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLMATHS_METADATA = Metadata(
    id="1a225d72bab397cfbf6f9e8837981a20bb223bbd.boutiques",
    name="fslmaths",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslmathsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslmaths(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output image"""


def fslmaths(
    infile: InputPathType,
    runner: Runner | None = None,
) -> FslmathsOutputs:
    """
    General command for mathematical manipulation of image intensities and
    generation of statistical data from given images.
    
    Author: FMRIB Analysis Group, Oxford University, UK
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        infile: Input image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslmathsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLMATHS_METADATA)
    cargs = []
    cargs.append("fslmaths")
    cargs.append(execution.input_file(infile))
    cargs.append("[OPERATIONS]")
    cargs.append("[OUTPUT_FILE]")
    ret = FslmathsOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLMATHS_METADATA",
    "FslmathsOutputs",
    "fslmaths",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SUMA_MAKE_SPEC_FS_METADATA = Metadata(
    id="91220aca63e7f033b6d7c13168d75d2a31651a2d.boutiques",
    name="@SUMA_Make_Spec_FS",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSumaMakeSpecFsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__suma_make_spec_fs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    suma_output: OutputPathType
    """All created files are stored in a new SUMA directory"""


def v__suma_make_spec_fs(
    subject_id: str,
    runner: Runner | None = None,
) -> VSumaMakeSpecFsOutputs:
    """
    Prepare for surface viewing in SUMA.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@SUMA_Make_Spec_FS.html
    
    Args:
        subject_id: Required subject ID for file naming.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSumaMakeSpecFsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SUMA_MAKE_SPEC_FS_METADATA)
    cargs = []
    cargs.append("@SUMA_Make_Spec_FS")
    cargs.append("[OPTIONS]")
    cargs.append("-sid")
    cargs.extend([
        "-sid",
        subject_id
    ])
    ret = VSumaMakeSpecFsOutputs(
        root=execution.output_file("."),
        suma_output=execution.output_file("SUMA/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSumaMakeSpecFsOutputs",
    "V__SUMA_MAKE_SPEC_FS_METADATA",
    "v__suma_make_spec_fs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DCLUST_METADATA = Metadata(
    id="af5ec3a11927a6c957d30f3fa58051ca30dde8d5.boutiques",
    name="3dclust",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dclustOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dclust(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    prefixed_output: OutputPathType
    """New dataset with clusters set to zero based on prefix."""
    ordered_mask_output: OutputPathType
    """Ordered mask dataset based on savemask prefix."""


def v_3dclust(
    datasets: list[InputPathType],
    runner: Runner | None = None,
) -> V3dclustOutputs:
    """
    Performs simple-minded cluster detection in 3D datasets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dclust.html
    
    Args:
        datasets: Input dataset(s). More than one allowed, but only the first\
            sub-brick of the dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dclustOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DCLUST_METADATA)
    cargs = []
    cargs.append("3dclust")
    cargs.append("[EDITING_OPTIONS]")
    cargs.append("[OTHER_OPTIONS]")
    cargs.append("[CLUSTERING_TYPE]")
    cargs.extend([execution.input_file(f) for f in datasets])
    ret = V3dclustOutputs(
        root=execution.output_file("."),
        prefixed_output=execution.output_file("[PREFIX].nii.gz"),
        ordered_mask_output=execution.output_file("[SAVEMASK].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dclustOutputs",
    "V_3DCLUST_METADATA",
    "v_3dclust",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DPLOT_METADATA = Metadata(
    id="5c20ed814370f7a719a7f440848c6bf24b99c20d.boutiques",
    name="1dplot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dplotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dplot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_1dplot(
    tsfiles: list[InputPathType],
    runner: Runner | None = None,
) -> V1dplotOutputs:
    """
    Graphs the columns of a *.1D time series file to the X11 screen, or to an image
    file (.jpg or .png).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dplot.html
    
    Args:
        tsfiles: Input time series files (*.1D) to be plotted.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dplotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DPLOT_METADATA)
    cargs = []
    cargs.append("1dplot")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in tsfiles])
    ret = V1dplotOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dplotOutputs",
    "V_1DPLOT_METADATA",
    "v_1dplot",
]



"""
ANTs

Advanced Normalization Tools (ANTs) is a C++ library available through the
command line that computes high-dimensional mappings to capture the statistics
of brain structure and function. It allows one to organize, visualize and
statistically explore large biomedical image sets. Additionally, it integrates
imaging modalities in space + time and works across species or organ systems
with minimal customization.

The ANTs library is considered a state-of-the-art medical image registration and
segmentation toolkit which depends on the Insight ToolKit, a widely used medical
image processing library to which ANTs developers contribute. ANTs-related tools
have also won several international, unbiased competitions such as MICCAI,
BRATS, and STACOM.

URL: https://github.com/ANTsX/ANTs
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .ants_registration_syn_sh import *
from .apply_transforms import *
from .atropos import *
from .atropos_n4 import *
from .brain_extraction_sh import *
from .denoise_image import *
from .multiply_images import *
from .n4_bias_field_correction import *
from .registration import *



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_FLAG_MOTION_METADATA = Metadata(
    id="12ffa6b4e618d89798e3c857043643e105256e61.boutiques",
    name="1dFlagMotion",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dFlagMotionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_flag_motion(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_points: OutputPathType
    """List of points exceeding the motion bounds in 1D format"""


def v_1d_flag_motion(
    input_motion_file: InputPathType,
    max_translation: float | None = None,
    max_rotation: float | None = None,
    runner: Runner | None = None,
) -> V1dFlagMotionOutputs:
    """
    Produces a list of time points with excessive motion relative to the previous
    time point.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dFlagMotion.html
    
    Args:
        input_motion_file: Input file with EXACTLY 6 columns: roll pitch yaw\
            delta-SI delta-LR delta-AP (angles in degrees followed by translations\
            in mm).
        max_translation: Maximum translation allowed in any direction (defaults\
            to 1.5mm).
        max_rotation: Maximum rotation allowed in any direction (defaults to\
            1.25 degrees).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dFlagMotionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_FLAG_MOTION_METADATA)
    cargs = []
    cargs.append("1dFlagMotion")
    cargs.append(execution.input_file(input_motion_file))
    if max_translation is not None:
        cargs.extend([
            "-MaxTrans",
            str(max_translation)
        ])
    if max_rotation is not None:
        cargs.extend([
            "-MaxRot",
            str(max_rotation)
        ])
    ret = V1dFlagMotionOutputs(
        root=execution.output_file("."),
        output_points=execution.output_file("output_motion_points.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dFlagMotionOutputs",
    "V_1D_FLAG_MOTION_METADATA",
    "v_1d_flag_motion",
]
